@@ -1,5 +1,5 @@
-summary_new <- function() {
-  summary_class$new()
+summary_new <- function(seconds_interval = NULL) {
+  summary_class$new(seconds_interval = seconds_interval)
 }
 
 summary_class <- R6::R6Class(
@@ -9,31 +9,30 @@ summary_class <- R6::R6Class(
   portable = FALSE,
   cloneable = FALSE,
   public = list(
-    time = NULL,
+    dequeue = function() {
+      if (!is.null(self$queue)) {
+        message(self$queue, appendLF = FALSE)
+        self$queue <- NULL
+      }
+    },
     report_start = function() {
-      self$time <- proc.time()["elapsed"]
       cli_df_header(progress_init(path = tempfile())$cli_data())
     },
-    report_progress = function(progress) {
-      cli_df_body(progress$cli_data())
+    report_progress = function(progress, force = FALSE) {
+      self$queue <- cli_df_body(progress$cli_data(), print = FALSE)
+      self$poll()
     },
     report_error = function(error) {
     },
     report_started = function(target = NULL, progress) {
       self$report_progress(progress)
+      self$dequeue()
     },
     report_built = function(target = NULL, progress) {
       self$report_progress(progress)
     },
     report_skipped = function(target = NULL, progress) {
-      time <- proc.time()["elapsed"]
-      # nocov start
-      # Covered in tests/interactive/test-reporter.R.
-      if (time - self$time > 0.25) {
-        self$report_progress(progress)
-        self$time <- time
-      }
-      # nocov end
+      self$report_progress(progress)
     },
     report_errored = function(target = NULL, progress) {
       self$report_progress(progress)
@@ -43,6 +42,7 @@ summary_class <- R6::R6Class(
     },
     report_end = function(progress, seconds_elapsed = NULL) {
       self$report_progress(progress)
+      self$dequeue()
       message("")
     }
   )
