@@ -14,7 +14,7 @@ tar_make(reporter = "timestamp")
 
 tar_script({
   library(targets)
-  tar_option_set(error = "workspace")
+  tar_option_set(workspace_on_error = TRUE)
   list(
     tar_target(x, runif(1e7)),
     tar_target(y, stop(x[1]))
