@@ -16,7 +16,7 @@ tar_test("tar_glimpse()", {
 })
 
 tar_test("custom script and store args", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("visNetwork")
   expect_equal(tar_config_get("script"), path_script_default())
   expect_equal(tar_config_get("store"), path_store_default())
@@ -40,7 +40,7 @@ tar_test("custom script and store args", {
 })
 
 tar_test("custom script and store args with callr function", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("visNetwork")
   expect_equal(tar_config_get("script"), path_script_default())
   expect_equal(tar_config_get("store"), path_store_default())
